@@ -1,5 +1,5 @@
 from dnastack.client import *
 from .cli_config import commands as config_commands
-from .search import commands as search_commands
+from .dataconnect import commands as dataconnect_commands
 from .files import commands as file_commands
 from .auth import commands as auth_commands
