@@ -1,3 +1,4 @@
+from os import write
 import sys
 from dnastack.constants import *
 from datetime import datetime
@@ -7,6 +8,8 @@ import json
 from requests import HTTPError
 from dnastack.client.utils import handle_client_results, get_dataconnect_client
 from typing import Optional
+import io
+import csv
 
 
 def query(
@@ -29,11 +32,12 @@ def query(
             list(handle_client_results(results, dataconnect_url)), indent=4
         )
     else:
-        outputs = []
-        for res in handle_client_results(results, dataconnect_url):
-            data_row = map(str, res.values())
-            outputs.append(",".join(data_row))
-        output = "\n".join(outputs)
+        output = io.StringIO()
+        writer = csv.writer(output)
+        for res in handle_client_results(results, search_url):
+            data_row = map(lambda x: str(x).replace(",", "\,"), res.values())
+            writer.writerow(data_row)
+        output = output.getvalue()
 
     if download:
         # TODO: be able to specify output file
