@@ -3,17 +3,17 @@ import os
 auth_params = {
     "wallet_uri": "https://wallet.prod.dnastack.com/",
     "redirect_uri": "https://wallet.prod.dnastack.com/",
-    "client_id": "dnastack-cli",
-    "client_secret": "4FnZEngqOGYDCjUYDjkacVkdNXFunDExfIVeBOexkZPOUVbolVOpyZLsnxj6DTi2",
+    "client_id": "publisher-cli",
+    "client_secret": "xBmI87BDGdDkiVoJRJm1RgnHGy1MxpN1",
 }
 
 
-config_file_path = f"{os.path.expanduser('~')}/.dnastack/config.yaml"
 cli_directory = f"{os.path.expanduser('~')}/.dnastack"
-downloads_directory = f"{os.path.expanduser('~')}/.dnastack/downloads"
+config_file_path = f"{cli_directory}/config.yaml"
+downloads_directory = f"{cli_directory}/downloads"
 
 ACCEPTED_CONFIG_KEYS = [
-    "search-url",
+    "data-connect-url",
     "drs-url",
     "personal_access_token",
     "email",
@@ -24,6 +24,4 @@ ACCEPTED_CONFIG_KEYS = [
     "client-redirect-uri",
 ]
 
-auth_scopes = (
-    "openid drs-object:write drs-object:access search:info search:data search:query"
-)
+auth_scopes = "openid drs-object:write drs-object:access dataconnect:info dataconnect:data dataconnect:query"
